import { DownloadStatus, DownloaderOptions } from './types';
/**
 * GitbookDownloader class for converting Gitbook pages to markdown
 */
export declare class GitbookDownloader {
    private baseUrl;
    private status;
    private visitedUrls;
    private pages;
    private contentHash;
    private turndownService;
    private options;
    /**
     * Creates a new GitbookDownloader instance
     * @param baseUrl - The base URL of the Gitbook documentation
     * @param options - Configuration options
     */
    constructor(baseUrl: string, options?: DownloaderOptions);
    /**
     * Downloads and converts Gitbook content to markdown
     */
    download(): Promise<string>;
    /**
     * Attempts to fetch and parse the sitemap
     */
    private _fetchSitemap;
    /**
     * Processes a single URL
     */
    private _processUrl;
    /**
     * Splits an array into chunks for parallel processing
     */
    private _chunkArray;
    /**
     * Gets the current download status
     */
    getStatus(): DownloadStatus;
    /**
     * Fetches a page and handles retries
     */
    private _fetchPage;
    /**
     * Processes page content and extracts navigation links
     */
    private _processPageContent;
    /**
     * Clean up the content by removing empty elements and unnecessary attributes
     */
    private _cleanupContent;
    /**
     * Extracts navigation links from the page
     */
    private _extractNavLinks;
    /**
     * Generates the final markdown content
     */
    private _generateMarkdown;
    /**
     * Utility method for sleeping
     */
    private _sleep;
    /**
     * Utility method for hashing strings
     */
    private _hashString;
}
