/**
 * Status of the download process
 */
export interface DownloadStatus {
    totalPages: number;
    currentPage: number;
    currentUrl: string;
    status: 'idle' | 'downloading' | 'completed' | 'error';
    error?: string;
    startTime?: number;
    pagesScraped: string[];
    outputFile?: string;
    rateLimitReset?: number;
}
/**
 * Data structure for a single page
 */
export interface PageData {
    index: number;
    title: string;
    content: string;
    url: string;
}
/**
 * Configuration options for the downloader
 */
export interface DownloaderOptions {
    /** Delay between requests in milliseconds */
    delay?: number;
    /** Maximum number of retries for failed requests */
    maxRetries?: number;
    /** Delay between retries in milliseconds */
    retryDelay?: number;
    /** Custom headers to send with requests */
    headers?: Record<string, string>;
    /** Output file path for the markdown */
    outputPath?: string;
}
